(index-page)=
```{include} ../README.md
:relative-docs: docs/
:relative-images:
:start-line: 2
```

# Contents
```{toctree}
:maxdepth: 2

user_guide
examples
endpoints
reference
contributing
contributors
history
```
